import { FC, SyntheticEvent, ReactNode } from 'react';
import classNames from 'classnames';
import {
    PopoverProps,
    Stack,
    Headline,
    BodyText,
    Button,
    ButtonGroup,
} from '@servicetitan/design-system';
import * as Styles from '../feature-spotlight.module.css';

export interface TourPopoverProps extends PopoverProps {
    children?: ReactNode;
    currentStep?: number;
    endText?: string;
    headerText?: string;
    nextText?: string;
    onClose?: (e?: SyntheticEvent<HTMLElement>) => void;
    onNext?: (e?: SyntheticEvent<HTMLElement>) => void;
    totalStepCount?: number;
}

export const TourPopover: FC<TourPopoverProps> = ({
    children,
    currentStep = 1,
    endText = 'Close',
    headerText,
    nextText = 'Next',
    onClose,
    onNext,
    totalStepCount = 1,
}) => {
    return (
        <Stack
            direction="column"
            className={classNames(
                Styles.featurePopover,
                'Popper__body Popover__body Popover__body--open Popover--w-s p-x-3 p-y-2'
            )}
        >
            <Stack.Item className="m-t-half">
                {headerText && <Headline size="small">{headerText}</Headline>}
                {children}
                <Stack
                    direction="row"
                    alignItems="center"
                    justifyContent="space-between"
                    className="m-t-2 m-b-half"
                >
                    <BodyText subdued>
                        {currentStep + 1}/{totalStepCount}
                    </BodyText>
                    <ButtonGroup>
                        {currentStep !== totalStepCount - 1 && (
                            <Button fill="subtle" size="small" onClick={onClose}>
                                Skip
                            </Button>
                        )}
                        <Button size="small" onClick={onNext} primary>
                            {currentStep !== totalStepCount - 1 ? nextText : endText}
                        </Button>
                    </ButtonGroup>
                </Stack>
            </Stack.Item>
        </Stack>
    );
};
